import request from '@/utils/request'

// 查询【请填写功能名称】列表
export function listCategory(query) {
  return request({
    url: '/system/shopInspectionCategory/list',
    method: 'get',
    params: query
  })
}

// 查询【请填写功能名称】详细
export function getCategory(id) {
  return request({
    url: '/system/shopInspectionCategory/getById?id=' + id,
    method: 'get'
  })
}

// 新增【请填写功能名称】
export function addCategory(data) {
  return request({
    url: '/system/shopInspectionCategory/add',
    method: 'post',
    data: data
  })
}

// 修改【请填写功能名称】
export function updateCategory(data) {
  return request({
    url: '/system/shopInspectionCategory/edit',
    method: 'post',
    data: data
  })
}

// 删除【请填写功能名称】
export function delCategory(id) {
  return request({
    url: '/system/shopInspectionCategory/del?idList=' + id,
    method: 'post'
  })
}
